@@ -78,7 +78,7 @@ class CvtContext_Int(Cvt):
 
 class Cvt_Int_Shutdown(CvtContext_Int):
     cmd = "shutdown",
-    name = "shutdown"
+    block = "int-shutdown"
 
     def update(self, old, upd, new, int_name):
         # we only 'shutdown' if we are disabling the port ('no shutdown'
@@ -92,14 +92,14 @@ class Cvt_Int_Shutdown(CvtContext_Int):
 
 class Cvt_Int_VRFFwd(CvtContext_Int):
     cmd = "vrf-forwarding",
+    block = "int-vrf"
+    triggers = { "int-addr" }
 
     def remove(self, old, int_name):
         return [*self.enter(int_name), " no vrf forwarding"]
 
     def update(self, old, upd, new, int_name):
         return [*self.enter(int_name), " vrf forwarding " + new]
-        # TODO: need to find some way to trigger reapplication of IP
-        # information (address, HSRP, etc.)
 
 
 class Cvt_Int_ARPTime(CvtContext_Int):
@@ -173,6 +173,7 @@ class Cvt_Int_IPAccGrp(CvtContext_Int):
 
 class Cvt_Int_IPAddr(CvtContext_Int):
     cmd = "ip-address",
+    block = "int-addr"
 
     def remove(self, old, int_name):
         return [*self.enter(int_name), " no ip address"]
@@ -183,6 +184,7 @@ class Cvt_Int_IPAddr(CvtContext_Int):
 
 class Cvt_Int_IPAddrSec(CvtContext_Int):
     cmd = "ip-address-secondary", None
+    block = "int-addr"
 
     def remove(self, old, int_name, addr):
         return [*self.enter(int_name), " no ip address %s secondary" % addr]
@@ -505,6 +507,7 @@ class Cvt_Int_ServPol(CvtContext_Int):
 
 class Cvt_Int_StandbyIP(CvtContext_Int):
     cmd = "standby", "group", None, "ip"
+    block = "int-addr"
 
     def remove(self, old, int_name, grp):
         return [*self.enter(int_name), " no standby %d ip" % grp]
@@ -515,6 +518,7 @@ class Cvt_Int_StandbyIP(CvtContext_Int):
 
 class Cvt_Int_StandbyIPSec(CvtContext_Int):
     cmd = "standby", "group", None, "ip-secondary", None
+    block = "int-addr"
 
     def remove(self, old, int_name, grp, addr):
         return [*self.enter(int_name),
@@ -527,6 +531,7 @@ class Cvt_Int_StandbyIPSec(CvtContext_Int):
 
 class Cvt_Int_StandbyIPv6(CvtContext_Int):
     cmd = "standby", "group", None, "ipv6", None
+    block = "int-addr"
 
     def remove(self, old, int_name, grp, addr):
         return [*self.enter(int_name),
@@ -716,7 +721,7 @@ class Cvt_Int_XConn(CvtContext_Int):
 
 class Cvt_Int_NoShutdown(CvtContext_Int):
     cmd = "shutdown",
-    name = "no-shutdown"
+    block = "int-noshutdown"
 
     def update(self, old, upd, new, int_name):
         # we only 'no shutdown' if we are enabling the port ('shutdown'
@@ -1191,7 +1196,7 @@ class Cvt_VRF_AF_RT(CvtContext_VRF_AF):
 
 
 # the converters are all subclasses of Cvt (DiffConvert) which have the
-# 'command' attribute defined
+# 'cmd' attribute defined
 #
 # CiscoIOSDiffConfig._add_converters() (below) adds these into the list
 # of converter classes
